//+------------------------------------------------------------------+
//|                                      BCADX3Crossover_Ticket0.mq4 |
//|                      Copyright  2005, MetaQuotes Software Corp. |
//|                                       http://www.metaquotes.net/ |
//+------------------------------------------------------------------+
#define MAGICMA  20050610

extern double Lots               = 0.1;
extern double MaximumRisk        = 0.01;
extern int MaximumLots           = 2;
extern double DecreaseFactor     = 3;
extern double MovingPeriod       = 14;
extern double MovingShift        = 5;
extern double MovingPeriodS      = 21;
extern double MovingShiftS       = 3;
extern bool rsi                  = False;
extern bool sto                  = False;

//+------------------------------------------------------------------+
//| Calculate open positions                                         |
//+------------------------------------------------------------------+
int CalculateCurrentOrders(string symbol)
  {
   int buys=0,sells=0;
//----
   for(int i=0;i<OrdersTotal();i++)
     {
      if(OrderSelect(i,SELECT_BY_TICKET,MODE_TRADES)==false) break;
      if(OrderSymbol()==Symbol() && OrderMagicNumber()==MAGICMA)
        {
         if(OrderType()==OP_BUY)  buys++;
         if(OrderType()==OP_SELL) sells++;
        }
     }
//---- return orders volume
   if(buys>0) return(buys);
   else       return(-sells);
  }
//+------------------------------------------------------------------+
//| Calculate optimal lot size                                       |
//+------------------------------------------------------------------+
double LotsOptimized()
  {
   double lot=Lots;
   int    orders=HistoryTotal();     // history orders total
   int    losses=0;                  // number of losses orders without a break
//---- select lot size
   lot=NormalizeDouble(AccountFreeMargin()*MaximumRisk/1000.0,1);
//---- calcuulate number of losses orders without a break
   if(DecreaseFactor>0)
     {
      for(int i=orders-1;i>=0;i--)
        {
         if(OrderSelect(i,SELECT_BY_TICKET,MODE_HISTORY)==false) { Print("Error in history!"); break; }
         if(OrderSymbol()!=Symbol() || OrderType()>OP_SELL) continue;
         //----
         if(OrderProfit()>0) break;
         if(OrderProfit()<0) losses++;
        }
      if(losses>1) lot=NormalizeDouble(lot-lot*losses/DecreaseFactor,1);
     }
//---- return lot size
   if(lot<0.1) lot=0.1;
   return(lot);
  }
//+------------------------------------------------------------------+
//| Check for open order conditions                                  |
//+------------------------------------------------------------------+
void CheckForOpen()
  {
   
   double ma;
   double maa;   
   double adx;
   double adxa;
   double adxb; 
   double adxx;
   double adxaa;
   double adxbb;
   double adxtfh; 
   bool is_siesta=false;
   int    res;
//---- go trading only for first tiks of new bar
   if(Volume[0]>1) return;
//---- get Moving Average 
   ma=iMA(NULL,0,MovingPeriod,MovingShift,MODE_SMA,PRICE_CLOSE,5);
   maa=iMA(NULL,0,MovingPeriodS,MovingShiftS,MODE_SMA,PRICE_CLOSE,6);
   adx=iADX(NULL,0,7,PRICE_CLOSE,MODE_MAIN,0);
   adxa=iADX(NULL,0,14,PRICE_CLOSE,MODE_MAIN,0);
   adxb=iADX(NULL,0,21,PRICE_CLOSE,MODE_MAIN,0);
   adxx=iADX(NULL,0,7,PRICE_CLOSE,MODE_MAIN,1);
   adxaa=iADX(NULL,0,14,PRICE_CLOSE,MODE_MAIN,1);
   adxbb=iADX(NULL,0,21,PRICE_CLOSE,MODE_MAIN,1);
   adxtfh=iADX(NULL,PERIOD_H1,7,PRICE_CLOSE,MODE_MAIN,1);
   
//---- sell conditions
   if(sto>80 && rsi>70)
   sto=True;
   rsi=True;
   if((adx<adxx && adxa>adxaa && adxb>adxbb) && (adx>=+10) && (adxtfh>=-50))
      if(Hour()>=12 || Hour()<=18)  is_siesta=true;    
     {
      res=OrderSend(Symbol(),OP_SELL,LotsOptimized(),Bid,3,0,0,"",MAGICMA,0,Red);
      return;
     }
//---- buy conditions
   if(sto<20 && rsi<30)
   sto=True;
   rsi=True;
   if((adx>adxx && adxa<adxaa && adxb<adxbb) && (adx>=-10) && (adxtfh>=+50))
     if(Hour()>=12 || Hour()<18)  is_siesta=true;

     {
      res=OrderSend(Symbol(),OP_BUY,LotsOptimized(),Ask,3,0,0,"",MAGICMA,0,Blue);
      return;
     }
//----
  }
//+------------------------------------------------------------------+
//| Check for close order conditions                                 |
//+------------------------------------------------------------------+
void CheckForClose()
  {
   double ma;
   double maa; 
     
//---- go trading only for first tiks of new bar
   if(Volume[0]>1) return;
  
//----
   for(int i=0;i<OrdersTotal();i++)
     {
      if(OrderSelect(i,SELECT_BY_POS,MODE_TRADES)==false)        
      if(OrderMagicNumber()!=MAGICMA || OrderSymbol()!=Symbol()) continue;
      //---- check order type 
      if(OrderType()==OP_BUY)
        {
        if(ma<maa) OrderClose(OrderTicket(),OrderLots(),Bid,3,White);
         break;
        }
      if(OrderType()==OP_SELL)
        {
         if(ma>maa) OrderClose(OrderTicket(),OrderLots(),Ask,3,White);
         break;
        }
     }
//----
  }
//+------------------------------------------------------------------+
//| Start function                                                   |
//+------------------------------------------------------------------+
void start()
  {
//---- check for history and trading
   if(Bars<100 || IsTradeAllowed()==false) return;
//---- calculate open orders by current symbol
   if(CalculateCurrentOrders(Symbol())==0) CheckForOpen();
   else                                    CheckForClose();
//----
  }
//+------------------------------------------------------------------+